#!/usr/bin/perl
use warnings;
use strict;

##################################################################################################

## This code converts the summary files generated from the RMA files in MEGAN to bin_stats format
## Requires file : names_uniq.dmp
## USAGE : perl covert_rma2binstats <RMA_summary_filename>


##################################################################################################


my $names_taxid_prot_file = "names_uniq.dmp";
open(NAMES_IN,"$names_taxid_prot_file"); 
my %names_hash;
my %reverse_names_hash;
while (1)
{
	chomp (my $names_input = <NAMES_IN>);
	my @names_arr = split ('\t' , $names_input);
	if (@names_arr)
	{
		$names_hash{$names_arr[1]} = $names_arr[0];
		$reverse_names_hash{$names_arr[0]} = $names_arr[1];
	}
	last if eof(NAMES_IN);
}



my $RMA_FILE = $ARGV[0];
my $MIN_SUPPORT = 0;

	
my $file_name = $RMA_FILE;
#print "$file_name\t$taxa_name\n";
open(BIN_STAT,"$file_name") or die "BIN STAT FILE DOES NOT EXIST";
my %number_hash;
open(TEMP_OUT,">$file_name.$MIN_SUPPORT.bin_stats");
my $total_unassigned = 0;
my $total_assigned = 0;
my $total_nohits = 0;
while(<BIN_STAT>)
{
	my $FF1 = $_;
	chomp $FF1;
	#print "FILE OPENED LINE:$FF1\n";
	unless($FF1 =~ /^\@/)
	{
		my @assign_line = split(/\s/,$FF1);
		my $assign_tax_id = $assign_line[0];
		my $number = $assign_line[2];
		if($assign_tax_id > 0)
		{
			if($number < $MIN_SUPPORT)
			{
				$total_unassigned += $number;
			}
			else
			{
				if(exists $reverse_names_hash{$assign_tax_id})
				{
				$total_assigned += $number;
				print (TEMP_OUT "$assign_tax_id\t$reverse_names_hash{$assign_tax_id}\t$number\n");
				}
				else
				{
				#$total_assigned += $number;
				#print (TEMP_OUT "$assign_tax_id\tnotinlist\t$number\n");
				}
			}
			
		}
		if($assign_tax_id == -2)
		{
			$total_unassigned += $number;
			#print "ASSIGN_CHECK\n";
		}
		if($assign_tax_id == -1)
		{
			$total_nohits += $number;
		}
	}
	my $final_bin_stats = "$file_name.$MIN_SUPPORT.bin_stats";
	
}

print (TEMP_OUT "NO_HITS_FOUND\t----\t$total_nohits\n");
print (TEMP_OUT "UNASSIGNED\t----\t$total_unassigned\n");
print (TEMP_OUT "TOTAL ASSIGNMENTS = $total_assigned\n");
print "\nConverting Done...\n";


			
